module Main exposing (..)

import Browser
import Html exposing (Html, button, div, input, text)
import Html.Events exposing (onClick, onInput)
import Http
import Json.Encode as Encode

-- Model
type alias Model =
    { proof : String
    , feedback : String
    , response : String
    }

init : Model
init =
    { proof = ""
    , feedback = ""
    , response = ""
    }

-- Messages
type Msg
    = UpdateProof String
    | UpdateFeedback String
    | Submit
    | GotResponse (Result Http.Error String)

-- Update
update : Msg -> Model -> ( Model, Cmd Msg )
update msg model =
    case msg of
        UpdateProof proof ->
            ( { model | proof = proof }, Cmd.none )

        UpdateFeedback feedback ->
            ( { model | feedback = feedback }, Cmd.none )

        Submit ->
            ( model, submitFeedback model.proof model.feedback )

        GotResponse result ->
            case result of
                Ok response ->
                    ( { model | response = "Submitted! Tx: " ++ response }, Cmd.none )

                Err _ ->
                    ( { model | response = "Error submitting feedback" }, Cmd.none )

submitFeedback : String -> String -> Cmd Msg
submitFeedback proof feedback =
    Http.post
        { url = "http://localhost:3000/submit-feedback"
        , body = Http.jsonBody <|
            Encode.object
                [ ("proof", Encode.string proof)
                , ("feedback", Encode.string feedback)
                ]
        , expect = Http.expectString GotResponse
        }

-- View
view : Model -> Html Msg
view model =
    div []
        [ div [] [ text "Proof:" ]
        , input [ onInput UpdateProof ] []
        , div [] [ text "Feedback:" ]
        , input [ onInput UpdateFeedback ] []
        , button [ onClick Submit ] [ text "Submit" ]
        , div [] [ text model.response ]
        ]

-- Main
main : Program () Model Msg
main =
    Browser.element
        { init = \_ -> ( init, Cmd.none )
        , update = update
        , view = view
        , subscriptions = \_ -> Sub.none
        }