"use client"

import { useState } from "react"
import { ArrowRight, CheckCircle, Clock, Edit, MessageSquare, VoteIcon } from "lucide-react"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Tabs, TabsContent, TabsList, TabsTrigger } from "@/components/ui/tabs"
import { Avatar, AvatarFallback } from "@/components/ui/avatar"
import { Badge } from "@/components/ui/badge"
import { Input } from "@/components/ui/input"
import { Label } from "@/components/ui/label"
import { ConnectWalletButton } from "@/components/connect-wallet-button"

// Mock data
const mockPerspectives = [
  {
    id: 1,
    title: "Improve bike lane safety",
    issue: "Infrastructure",
    date: "2024-02-10",
    status: "Synthesized",
  },
  {
    id: 2,
    title: "Expand library hours",
    issue: "Education",
    date: "2024-01-25",
    status: "Synthesized",
  },
  {
    id: 3,
    title: "Community garden proposal",
    issue: "Environmental Policy",
    date: "2024-01-15",
    status: "Pending",
  },
]

const mockVotes = [
  {
    id: 1,
    insight: "Increase Park Funding",
    vote: "Yes",
    date: "2024-02-15",
  },
  {
    id: 2,
    insight: "Public Transportation Expansion",
    vote: "Yes",
    date: "2024-02-10",
  },
  {
    id: 3,
    insight: "After-School Programs",
    vote: "Yes",
    date: "2024-01-28",
  },
  {
    id: 4,
    insight: "Bike Lane Network",
    vote: "No",
    date: "2024-01-20",
  },
]

export default function ProfilePage() {
  const [walletConnected, setWalletConnected] = useState(false)
  const [delegateAddress, setDelegateAddress] = useState("")

  return (
    <div className="container mx-auto px-4 py-8">
      <div className="mb-8">
        <h1 className="text-3xl font-bold">Profile</h1>
        <p className="mt-2 text-muted-foreground">Manage your participation and delegation settings</p>
      </div>

      {!walletConnected ? (
        <Card className="mx-auto max-w-md">
          <CardHeader>
            <CardTitle>Connect Your Wallet</CardTitle>
            <CardDescription>Connect your wallet to view your profile and participation history</CardDescription>
          </CardHeader>
          <CardContent className="flex justify-center py-6">
            <ConnectWalletButton onConnect={() => setWalletConnected(true)} />
          </CardContent>
        </Card>
      ) : (
        <div className="grid grid-cols-1 gap-8 lg:grid-cols-3">
          {/* Profile Card */}
          <Card className="lg:col-span-1">
            <CardHeader>
              <CardTitle>Your Profile</CardTitle>
            </CardHeader>
            <CardContent className="flex flex-col items-center">
              <Avatar className="h-24 w-24">
                <AvatarFallback className="text-xl">VP</AvatarFallback>
              </Avatar>
              <div className="mt-4 text-center">
                <h3 className="text-lg font-medium">VoxPop User</h3>
                <p className="text-sm text-muted-foreground">0x1a2...3b4c</p>
              </div>
              <div className="mt-6 grid w-full grid-cols-2 gap-4 text-center">
                <div>
                  <p className="text-2xl font-bold">{mockPerspectives.length}</p>
                  <p className="text-sm text-muted-foreground">Perspectives</p>
                </div>
                <div>
                  <p className="text-2xl font-bold">{mockVotes.length}</p>
                  <p className="text-sm text-muted-foreground">Votes</p>
                </div>
              </div>
              <div className="mt-6 w-full">
                <Button variant="outline" className="w-full" asChild>
                  <a href="/settings">
                    <Edit className="mr-2 h-4 w-4" />
                    Edit Profile
                  </a>
                </Button>
              </div>
            </CardContent>
          </Card>

          {/* Activity Tabs */}
          <div className="lg:col-span-2">
            <Tabs defaultValue="perspectives">
              <TabsList className="grid w-full grid-cols-2">
                <TabsTrigger value="perspectives">Your Perspectives</TabsTrigger>
                <TabsTrigger value="votes">Your Votes</TabsTrigger>
              </TabsList>

              <TabsContent value="perspectives" className="mt-6">
                <div className="rounded-lg border">
                  {mockPerspectives.map((perspective, index) => (
                    <div
                      key={perspective.id}
                      className={`flex items-center justify-between p-4 ${
                        index !== mockPerspectives.length - 1 ? "border-b" : ""
                      }`}
                    >
                      <div className="flex items-start gap-3">
                        <div className="rounded-full bg-primary/10 p-2">
                          <MessageSquare className="h-4 w-4 text-primary" />
                        </div>
                        <div>
                          <p className="font-medium">{perspective.title}</p>
                          <p className="text-sm text-muted-foreground">
                            {perspective.issue} • {new Date(perspective.date).toLocaleDateString()}
                          </p>
                        </div>
                      </div>
                      <Badge variant={perspective.status === "Synthesized" ? "default" : "outline"}>
                        {perspective.status === "Synthesized" ? (
                          <CheckCircle className="mr-1 h-3 w-3" />
                        ) : (
                          <Clock className="mr-1 h-3 w-3" />
                        )}
                        {perspective.status}
                      </Badge>
                    </div>
                  ))}
                </div>
                <div className="mt-4 flex justify-center">
                  <Button asChild>
                    <a href="/submit">
                      Submit New Perspective
                      <ArrowRight className="ml-2 h-4 w-4" />
                    </a>
                  </Button>
                </div>
              </TabsContent>

              <TabsContent value="votes" className="mt-6">
                <div className="rounded-lg border">
                  {mockVotes.map((vote, index) => (
                    <div
                      key={vote.id}
                      className={`flex items-center justify-between p-4 ${
                        index !== mockVotes.length - 1 ? "border-b" : ""
                      }`}
                    >
                      <div className="flex items-start gap-3">
                        <div className="rounded-full bg-primary/10 p-2">
                          <VoteIcon className="h-4 w-4 text-primary" />
                        </div>
                        <div>
                          <p className="font-medium">{vote.insight}</p>
                          <p className="text-sm text-muted-foreground">
                            Voted {vote.vote} • {new Date(vote.date).toLocaleDateString()}
                          </p>
                        </div>
                      </div>
                      <Badge variant={vote.vote === "Yes" ? "default" : "destructive"}>{vote.vote}</Badge>
                    </div>
                  ))}
                </div>
                <div className="mt-4 flex justify-center">
                  <Button asChild>
                    <a href="/insights">
                      View More Insights
                      <ArrowRight className="ml-2 h-4 w-4" />
                    </a>
                  </Button>
                </div>
              </TabsContent>
            </Tabs>
          </div>

          {/* Delegation Settings */}
          <Card className="lg:col-span-3">
            <CardHeader>
              <CardTitle>Delegation Settings</CardTitle>
              <CardDescription>
                Delegate your voting power to trusted representatives (liquid democracy)
              </CardDescription>
            </CardHeader>
            <CardContent>
              <div className="grid gap-4 md:grid-cols-2">
                <div>
                  <Label htmlFor="delegate-address">Delegate Address</Label>
                  <div className="mt-1.5 flex gap-2">
                    <Input
                      id="delegate-address"
                      placeholder="0x..."
                      value={delegateAddress}
                      onChange={(e) => setDelegateAddress(e.target.value)}
                    />
                    <Button variant="outline" disabled={!delegateAddress}>
                      Delegate
                    </Button>
                  </div>
                  <p className="mt-2 text-xs text-muted-foreground">
                    Enter the wallet address of the person you want to delegate your votes to
                  </p>
                </div>
                <div className="rounded-lg border p-4">
                  <h3 className="font-medium">Current Delegation</h3>
                  <p className="mt-2 text-sm text-muted-foreground">
                    You are not currently delegating your votes to anyone.
                  </p>
                  <p className="mt-4 text-xs text-muted-foreground">
                    When you delegate your votes, the delegate can vote on your behalf, but you can always override
                    their vote.
                  </p>
                </div>
              </div>
            </CardContent>
          </Card>
        </div>
      )}
    </div>
  )
}

