import { create } from "zustand"
import { persist } from "zustand/middleware"

interface WalletState {
  walletConnected: boolean
  walletAddress: string
  username: string | null
  connectWallet: (address?: string, username?: string) => void
  disconnectWallet: () => void
}

export const useWalletStore = create<WalletState>()(
  persist(
    (set) => ({
      walletConnected: false,
      walletAddress: "",
      username: null,
      connectWallet: (address = "0x1a2...3b4c", username = "VoxPop User") =>
        set({ walletConnected: true, walletAddress: address, username }),
      disconnectWallet: () => set({ walletConnected: false, walletAddress: "", username: null }),
    }),
    {
      name: "wallet-storage",
    },
  ),
)

